package com.brilliance.isc.basesel.trncod.service.impl;

import com.brilliance.mda.runtime.mda.util.MdaUtils;
import com.brilliance.isc.basesel.trncod.consts.ErrorPrompt;
import com.brilliance.isc.basesel.trncod.service.TrncodService;
import com.brilliance.isc.bo.Busbtn;
import com.brilliance.isc.bo.Trn;
import com.brilliance.isc.bo.model.*;
import com.brilliance.isc.bo.remit.CptadvStoreBo;
import com.brilliance.isc.bo.remit.CptopnStoreBo;
import com.brilliance.isc.common.component.CpToolComponent;
import com.brilliance.isc.common.sysmod.SysmodService;
import com.brilliance.isc.mda.dao.*;
import com.brilliance.isc.vo.TrnCodeQueryVo;
import com.brilliance.isc.vo.TrncodVo;
import com.google.common.collect.Lists;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import java.util.*;

@Service
public class TrncodServiceImpl implements TrncodService {

    @Resource
    private BusbtnMapper busbtnMapper;
    @Resource
    private TrncodService trncodService;
    @Resource
    private CpToolComponent cpToolComponent;
    @Resource
    private TrnMapper trnMapper;
    @Resource
    private SysmodService sysmodService;

    @Override
    public String isCPTrnAllowed(Cpdgrp cpdgrp, String trnNam) {
        cpdgrp.reset();
        trnNam = trnNam.toUpperCase();
        String errMsg = "";
        switch(trnNam){
            case "CPTADV":
                if(MdaUtils.isEmpty(cpdgrp.getRec().getInr())){
                    errMsg += ErrorPrompt.ErrSelN;
                }else {
                    if(!MdaUtils.isEmpty(cpdgrp.getRec().getClsdat())){
                        errMsg += ErrorPrompt.ErrClsY;
                    }
                    if(MdaUtils.isEmpty(cpdgrp.getRec().getOpndat())){
                        errMsg += ErrorPrompt.ErrOpnN;
                    }
                    if(!MdaUtils.equals(cpdgrp.getRec().getAccmod(),"2")){
                        errMsg += "业务未挂账！\n";
                    }
                }
                break;
            case "CPTCAN":
                if(MdaUtils.isEmpty(cpdgrp.getRec().getInr())){
                    errMsg += ErrorPrompt.ErrSelN;
                }else {
                    if (!MdaUtils.isEmpty(cpdgrp.getRec().getClsdat())) {
                        errMsg += ErrorPrompt.ErrClsY;
                    }
                }
                break;
            case "CPTROP":
                if(MdaUtils.isEmpty(cpdgrp.getRec().getInr())){
                    errMsg += ErrorPrompt.ErrSelN;
                }else {
                    if (MdaUtils.isEmpty(cpdgrp.getRec().getClsdat())) {
                        errMsg += ErrorPrompt.ErrClsN;
                    }
                }
                break;
            case "CPTFEE":
            case "CPTFRE":
            case "CPTATT":
            case "JSTOPN":
                if(MdaUtils.isEmpty(cpdgrp.getRec().getInr())){
                    errMsg += ErrorPrompt.ErrSelN;
                }
                break;
            default:
                errMsg += "";
                break;
        }
        return  errMsg;

    }



    @Override
    public List<TrncodVo> dealWithByInr(TrnCodeQueryVo trnCodeQueryVo) {
        List<TrncodVo> result = Lists.newArrayList();
        //获取模型数据
        Cpdgrp cpdgrp = cpToolComponent.getCpdgrpByInr(trnCodeQueryVo.getInr());
        List<Busbtn> busbtnList = busbtnMapper.selectByBustypAndIsShow(trnCodeQueryVo.getType());
        String disResult = "";
        for (int i = 0; i < busbtnList.size(); i++) {
            //按钮亮灰显逻辑
            disResult =  trncodService.isCPTrnAllowed(cpdgrp,busbtnList.get(i).getInifrm());
            TrncodVo trncodVo = new TrncodVo(busbtnList.get(i).getInifrm(), busbtnList.get(i).getBtnnam(), MdaUtils.isEmpty(disResult) ? "Y" : "N", busbtnList.get(i).getIsMain(), disResult);
            result.add(trncodVo);
        }
        return result;
    }

    @Override
    public Object selectXxdByPrimaryKey(Map<String, String> map) {
        String objinr = map.get("objinr");
        String objtyp = map.get("objtyp");
        String pntinr = map.get("pntinr");
        String paytyp = map.get("paytyp");
        switch(paytyp) {
            case "I":
                CptadvStoreBo cptadvStoreBo = new CptadvStoreBo();
                cptadvStoreBo.reset();
                if(objinr.length() == 16) {
                    Trn trnCpdI = trnMapper.selectByObjinrTrn(objtyp, objinr, "CPTADV");
                    if (!Objects.isNull(trnCpdI)) {
                        cptadvStoreBo = sysmodService.streamGetNameInSubDir(CptadvStoreBo.class, trnCpdI.getInr());
                    }
                }
                cptadvStoreBo.setCpdgrp(cpToolComponent.getCpdgrpByInr(objinr));
                return cptadvStoreBo;
            case "O":
                CptopnStoreBo cptopnStoreBo = new CptopnStoreBo();
                cptopnStoreBo.reset();
                if(objinr.length() == 16) {
                    Trn trnCpdO = trnMapper.selectByObjinrTrn(objtyp, objinr, "CPTOPN");
                    if (!Objects.isNull(trnCpdO)) {
                        cptopnStoreBo = sysmodService.streamGetNameInSubDir(CptopnStoreBo.class, trnCpdO.getInr());
                    }
                }
                cptopnStoreBo.setCpdgrp(cpToolComponent.getCpdgrpByInr(objinr));
                return cptopnStoreBo;
        }
        return null;
    }

}
